/*
 * Decompiled with CFR 0.152.
 * 
 * Could not load the following classes:
 *  org.apache.commons.logging.Log
 *  org.apache.commons.logging.LogFactory
 *  org.springframework.beans.factory.annotation.Autowired
 *  org.springframework.stereotype.Repository
 */
package com.hst.task.dao;

import com.hst.framework.common.HstSqlMapClientTemplate;
import com.hst.framework.dao.BaseDao;
import com.hst.task.domain.NsfwJhGt3StatusDto;
import com.hst.task.domain.ZhdtCkryImageDto;
import java.util.HashMap;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

@Repository
public class NsfwSjscDaoImp
implements BaseDao {
    public static Log _logger = LogFactory.getLog(NsfwSjscDaoImp.class);
    @Autowired
    private HstSqlMapClientTemplate nsfwSjscSqlMapClientTemplate;

    public List<ZhdtCkryImageDto> queryCkryImgDownloadList() throws Exception {
        HashMap map = new HashMap();
        this.nsfwSjscSqlMapClientTemplate.queryForObjectByCurr("pZhdtTaskCkryimg", "dataList", map);
        String cfr_ignored_0 = (String)map.get("code");
        String cfr_ignored_1 = (String)map.get("mess");
        List dataList = (List)map.get("dataList");
        return dataList;
    }

    public void updateCkryImgZt(ZhdtCkryImageDto bo) {
        this.nsfwSjscSqlMapClientTemplate.update("updateCkryImgZt", bo);
    }

    public List<NsfwJhGt3StatusDto> queryGt3CheckList() throws Exception {
        HashMap map = new HashMap();
        this.nsfwSjscSqlMapClientTemplate.queryForObjectByCurr("pZhdtTaskGt3Staus", "dataList", map);
        String cfr_ignored_0 = (String)map.get("code");
        String cfr_ignored_1 = (String)map.get("mess");
        List dataList = (List)map.get("dataList");
        return dataList;
    }

    public void updateNSfwJhGt3Status(NsfwJhGt3StatusDto bo) {
        this.nsfwSjscSqlMapClientTemplate.update("updateNSfwJhGt3Status", bo);
    }
}
